pub struct ApiError {
pub request_id: Option<String>,
pub status_code: StatusCode,
pub case: Option<String>,
pub message: String,
pub docs_url: Option<String>,
pub payload: Option<Box<HashMap<String, Value>>>,
}Available on crate feature
historical only.Expand description
An error from the Databento API.
Fields
request_id: Option<String>The request ID.
status_code: StatusCodeThe HTTP status code of the response.
case: Option<String>A machine-readable identifier for the error case, when the server returns a
structured error envelope. None for unstructured errors.
message: StringThe message from the Databento API.
docs_url: Option<String>The link to documentation related to the error.
payload: Option<Box<HashMap<String, Value>>>Additional context for the error, when the server provides one. Common keys
include dataset, start, end, available_start, and available_end.