Module historical

Module historical 

Available on crate feature historical only.
Historical client and related API types.

Modules

batch
The historical batch download API.
metadata
The historical metadata download API.
symbology
The historical symbology API.
timeseries
The historical timeseries API.

Structs

Client
The Historical client. Used for symbology resolutions, metadata requests, Historical data older than 24 hours, and submitting batch downloads.
ClientBuilder
A type-safe builder for the HistoricalClient. It will not allow you to call Self::build() before setting the required key field.
DateRange
A half-closed date interval with an inclusive UTC start date and an exclusive UTC end date.
DateTimeRange
A half-closed datetime interval with an inclusive start and an exclusive end.

Enums

HistoricalGateway
The Historical API gateway to use.

Constants

API_VERSION
The current Databento historical API version.