pub enum DatasetCondition {
Available,
Degraded,
Pending,
Missing,
}Available on crate feature
historical only.Expand description
The condition of a dataset on a day.
Variants
Available
The data is available with no known issues.
Degraded
The data is available, but there may be missing data or other correctness issues.
Pending
The data is not yet available, but may be available soon.
Missing
The data is not available.
Implementations