Module live

Module live 

Available on crate feature live only.
The Live client and related API types. Used for both real-time data and intraday historical.

Modules

protocol
Lower-level live interfaces exposed for those who want more customization or control.

Structs

Client
The Live client. Used for subscribing to real-time and intraday historical market data.
ClientBuilder
A type-safe builder for the LiveClient. It will not allow you to call Self::build() before setting the required fields:
Subscription
A subscription for real-time or intraday historical data.
SubscriptionBuilder
Use builder syntax to set the inputs and finish with build().
TimeoutConf
Timeouts for the Live client’s connection and authentication phases.

Enums

SlowReaderBehavior
Live session parameter which controls gateway behavior when the client falls behind real time.