ClientBuilder

Struct ClientBuilder 

pub struct ClientBuilder<AK, D> { /* private fields */ }
Available on crate feature live only.
A type-safe builder for the LiveClient. It will not allow you to call Self::build() before setting the required fields:

  • key
  • dataset

Implementations

Source

impl<AK, D> ClientBuilder<AK, D>

pub fn send_ts_out(self, send_ts_out: bool) -> Self

Sets ts_out, which when enabled instructs the gateway to send a send timestamp after every record. These can be decoded with the special WithTsOut type.

pub fn upgrade_policy(self, upgrade_policy: VersionUpgradePolicy) -> Self

Sets upgrade_policy, which controls how to decode data from prior DBN versions. The current default is to upgrade them to the latest version while decoding.

pub fn heartbeat_interval(self, heartbeat_interval: Duration) -> Self

Sets heartbeat_interval, which controls the interval at which the gateway will send heartbeat records if no other data records are sent. If no heartbeat interval is configured, the gateway default will be used. Minimum interval is 5 seconds.

Note that granularity of less than a second is not supported and will be ignored.

pub fn buffer_size(self, size: usize) -> Self

Sets the initial size of the internal buffer used for reading data from the TCP socket.

pub async fn addr(self, addr: impl ToSocketAddrs) -> Result<Self>

Overrides the address of the gateway the client will connect to. This is an advanced method.

Errors

This function returns an error when addr fails to resolve.

pub fn user_agent_extension(self, extension: String) -> Self

Extends the user agent. Intended for library authors.

pub fn compression(self, compression: Compression) -> Self

Sets the compression mode for the read stream. Default is Compression::None.

pub fn slow_reader_behavior( self, slow_reader_behavior: SlowReaderBehavior, ) -> Self

Sets the behavior of the gateway when the client falls behind real time.

Source

impl ClientBuilder<Unset, Unset>

pub fn new() -> Self

Creates a new ClientBuilder.

Source

impl<D> ClientBuilder<Unset, D>

pub fn key(self, key: impl ToString) -> Result<ClientBuilder<ApiKey, D>>

Sets the API key.

Errors

This function returns an error when the API key is invalid.

pub fn key_from_env(self) -> Result<ClientBuilder<ApiKey, D>>

Sets the API key reading it from the DATABENTO_API_KEY environment variable.

Errors

This function returns an error when the environment variable is not set or the API key is invalid.

Source

impl<AK> ClientBuilder<AK, Unset>

pub fn dataset(self, dataset: impl ToString) -> ClientBuilder<AK, String>

Sets the dataset.

Source

impl ClientBuilder<ApiKey, String>

pub async fn build(self) -> Result<Client>

Initializes the client and attempts to connect to the gateway.

Errors

This function returns an error when its unable to connect and authenticate with the Live gateway.