pub struct Subscription {
pub symbols: Symbols,
pub schema: Schema,
pub stype_in: SType,
pub start: Option<OffsetDateTime>,
pub use_snapshot: bool,
pub id: Option<u32>,
}Available on crate feature
live only.Expand description
A subscription for real-time or intraday historical data.
Fields
symbols: SymbolsThe symbols of the instruments to subscribe to.
schema: SchemaThe data record schema of data to subscribe to.
stype_in: STypeThe symbology type of the symbols in symbols.
start: Option<OffsetDateTime>The inclusive start of subscription replay.
Pass OffsetDateTime::UNIX_EPOCH to request all available data.
When None, only real-time data is sent.
Cannot be specified after the session is started with LiveClient::start.
See Intraday Replay.
use_snapshot: boolRequest subscription with snapshot. Only supported with Mbo schema.
Defaults to false. Conflicts with the start parameter.
id: Option<u32>The optional numerical identifier associated with this subscription.
Implementations
Sourceimpl Subscription
impl Subscription
Sourcepub fn builder() -> SubscriptionBuilder
pub fn builder() -> SubscriptionBuilder
Create an instance of Subscription using the builder syntax