pub struct SubscriptionBuilder<S: State = Empty> { /* private fields */ }live only.Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> SubscriptionBuilder<S>
impl<S: State> SubscriptionBuilder<S>
Sourcepub fn build(self) -> Subscriptionwhere
S: IsComplete,
pub fn build(self) -> Subscriptionwhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn symbols(
self,
value: impl Into<Symbols>,
) -> SubscriptionBuilder<SetSymbols<S>>where
S::Symbols: IsUnset,
pub fn symbols(
self,
value: impl Into<Symbols>,
) -> SubscriptionBuilder<SetSymbols<S>>where
S::Symbols: IsUnset,
Required.
The symbols of the instruments to subscribe to.
Sourcepub fn schema(self, value: Schema) -> SubscriptionBuilder<SetSchema<S>>where
S::Schema: IsUnset,
pub fn schema(self, value: Schema) -> SubscriptionBuilder<SetSchema<S>>where
S::Schema: IsUnset,
Required.
The data record schema of data to subscribe to.
Sourcepub fn stype_in(self, value: SType) -> SubscriptionBuilder<SetStypeIn<S>>where
S::StypeIn: IsUnset,
pub fn stype_in(self, value: SType) -> SubscriptionBuilder<SetStypeIn<S>>where
S::StypeIn: IsUnset,
Sourcepub fn maybe_stype_in(
self,
value: Option<SType>,
) -> SubscriptionBuilder<SetStypeIn<S>>where
S::StypeIn: IsUnset,
pub fn maybe_stype_in(
self,
value: Option<SType>,
) -> SubscriptionBuilder<SetStypeIn<S>>where
S::StypeIn: IsUnset,
Sourcepub fn start(self, dt: impl DateTimeLike) -> SubscriptionBuilder<SetStart<S>>where
S::Start: IsUnset,
pub fn start(self, dt: impl DateTimeLike) -> SubscriptionBuilder<SetStart<S>>where
S::Start: IsUnset,
Optional (Some / Option setters).
The inclusive start of subscription replay.
Pass OffsetDateTime::UNIX_EPOCH to request all available data.
When None, only real-time data is sent.
Cannot be specified after the session is started with LiveClient::start.
See Intraday Replay.
Sourcepub fn maybe_start(
self,
value: Option<impl DateTimeLike>,
) -> SubscriptionBuilder<SetStart<S>>where
S::Start: IsUnset,
pub fn maybe_start(
self,
value: Option<impl DateTimeLike>,
) -> SubscriptionBuilder<SetStart<S>>where
S::Start: IsUnset,
Optional (Some / Option setters).
The inclusive start of subscription replay.
Pass OffsetDateTime::UNIX_EPOCH to request all available data.
When None, only real-time data is sent.
Cannot be specified after the session is started with LiveClient::start.
See Intraday Replay.