AdjustmentFactor

Struct AdjustmentFactor 

pub struct AdjustmentFactor {
Show 28 fields pub security_id: String, pub event_id: String, pub event: Event, pub issuer_name: String, pub security_type: SecurityType, pub primary_exchange: Option<String>, pub exchange: Option<String>, pub operating_mic: String, pub symbol: Option<String>, pub nasdaq_symbol: Option<String>, pub local_code: Option<String>, pub local_code_resulting: Option<String>, pub isin: Option<String>, pub isin_resulting: Option<String>, pub us_code: Option<String>, pub status: AdjustmentStatus, pub ex_date: Date, pub factor: f64, pub close: Option<f64>, pub currency: Option<String>, pub sentiment: f64, pub reason: u32, pub gross_dividend: Option<f64>, pub dividend_currency: Option<Currency>, pub frequency: Option<Frequency>, pub option: u32, pub detail: String, pub ts_created: OffsetDateTime,
}
Available on crate feature historical only.
A record in the adjustment factor response.

Fields

security_id: String

Security level numerical ID. Can be used to link all multiple listings together.

event_id: String

Event identifier unique at the event level. Links to the corporate actions event_id.

event: Event

The event type.

issuer_name: String

The issuer name.

security_type: SecurityType

The security type.

primary_exchange: Option<String>

Exchange code for the primary security.

exchange: Option<String>

Exchange code for the listing. Equivalent to the MIC but more stable as MIC might not be available in a timely fashion. Also note that the MIC can change but the exchange will remain the same.

operating_mic: String

Market Identifier Code (MIC) as an ISO 10383 string.

symbol: Option<String>

The query input symbol which matched the record.

nasdaq_symbol: Option<String>

Nasdaq Integrated Platform Suffix convention symbol.

local_code: Option<String>

Local Code. Usually unique at market level but there are exceptions to this rule. Either an alpha string, or a number.

local_code_resulting: Option<String>

Resultant local code when applicable/known.

isin: Option<String>

ISIN global level identifier as an ISO 6166 string.

isin_resulting: Option<String>

Resultant ISIN when applicable/known.

us_code: Option<String>

US domestic CUSIP.

status: AdjustmentStatus

The adjustment status.

ex_date: Date

Date from which the event is effective.

factor: f64

Adjustment factor to apply.

close: Option<f64>

Closing price on the ex_date.

currency: Option<String>

Currency for the closing price.

sentiment: f64

Market sentiment - the market’s reaction to the event. Simply the previous close divided by today’s open. Only correct if factor calculation requires previous close.

reason: u32

Reason/type of event, used to distinguish between different event types.

gross_dividend: Option<f64>

The amount of the dividend before any taxes or fees are deducted. This value represents the total dividend declared by the company.

dividend_currency: Option<Currency>

The currency in which the dividend is paid.

frequency: Option<Frequency>

The frequency at which the dividend is paid.

option: u32

The choice or option number associated with the event, often used when shareholders are given multiple options for how they would like to receive the dividend or other corporate action benefit (either cash, or script).

detail: String

A human-readable description of the event.

ts_created: OffsetDateTime

The timestamp (UTC) the record was added by Databento.