pub enum Symbols {
All,
Ids(Vec<u32>),
Symbols(Vec<String>),
}Expand description
A set of symbols for a particular SType.
Variants
All
Sentinel value for all symbols in a dataset.
Ids(Vec<u32>)
A set of symbols identified by their instrument IDs.
Symbols(Vec<String>)
A set of symbols.
Implementations
Sourceimpl Symbols
impl Symbols
Sourcepub fn to_api_string(&self) -> String
pub fn to_api_string(&self) -> String
Returns the string representation for sending to the API.
Sourcepub fn to_chunked_api_string(&self) -> Vec<String>
Available on crate feature live only.
pub fn to_chunked_api_string(&self) -> Vec<String>
live only.Splits the symbol into chunks to stay within the message length requirements of the live gateway.