Available on crate feature
historical only.Expand description
Historical client and related API types.
Modules
- batch
- The historical batch download API.
- metadata
- The historical metadata download API.
- symbology
- The historical symbology API.
- timeseries
- The historical timeseries API.
Structs
- Client
- The Historical client. Used for symbology resolutions, metadata requests, Historical data older than 24 hours, and submitting batch downloads.
- Client
Builder - A type-safe builder for the
HistoricalClient. It will not allow you to callSelf::build()before setting the requiredkeyfield. - Date
Range - A half-closed date interval with an inclusive UTC start date and an exclusive UTC end date.
- Date
Time Range - A half-closed datetime interval with an inclusive start and an exclusive end.
Enums
- Historical
Gateway - The Historical API gateway to use.
Constants
- API_
VERSION - The current Databento historical API version.