pub struct GetRangeParams {
pub start: OffsetDateTime,
pub end: Option<OffsetDateTime>,
pub index: Index,
pub symbols: Symbols,
pub stype_in: SType,
pub countries: Vec<Country>,
pub security_types: Vec<SecurityType>,
}Available on crate feature
historical only.Expand description
The parameters for SecurityMasterClient::get_range(). Use
GetRangeParams::builder() to get a builder type with all the preset defaults.
Fields
start: OffsetDateTimeThe inclusive start time of the request range. Filters on index.
end: Option<OffsetDateTime>The exclusive end time of the request range. Filters on index.
If None, all data after start will be included in the response.
index: IndexThe timestamp to use for filtering.
symbols: SymbolsThe symbols to filter for.
stype_in: STypeThe symbology type of the input symbols. Defaults to
RawSymbol.
countries: Vec<Country>An optional list of country codes to filter for. By default all countries are included.
security_types: Vec<SecurityType>An optional list of security types to filter for. By default all security types are included.
Implementations
Sourceimpl GetRangeParams
impl GetRangeParams
Sourcepub fn builder() -> GetRangeParamsBuilder
pub fn builder() -> GetRangeParamsBuilder
Create an instance of GetRangeParams using the builder syntax